@@ -15,20 +15,19 @@
 
 #include "k3bmedium.h"
 #include "k3bmedium_p.h"
-
 #include "k3bcddb.h"
 #include "k3bdeviceglobals.h"
 #include "k3bglobals.h"
 #include "k3biso9660.h"
 #include "k3biso9660backend.h"
+#include "k3b_i18n.h"
 
-#include <klocale.h>
-#include <kio/global.h>
+#include <KIOCore/KIO/Global>
 
-#include <QtCore/QSharedData>
 #include <QtCore/QList>
+#include <QtCore/QSharedData>
 
-#include <libkcddb/cdinfo.h>
+#include <KCddb/Cdinfo>
 
 
 
@@ -183,13 +182,13 @@ void K3b::Medium::update()
         d->diskInfo = d->device->diskInfo();
 
         if( d->diskInfo.diskState() != K3b::Device::STATE_NO_MEDIA ) {
-            kDebug() << "found medium: (" << d->device->blockDeviceName() << ')' << endl
+            qDebug() << "found medium: (" << d->device->blockDeviceName() << ')' << endl
                      << "=====================================================";
             d->diskInfo.debug();
-            kDebug() << "=====================================================";
+            qDebug() << "=====================================================";
         }
         else {
-            kDebug() << "no medium found";
+            qDebug() << "no medium found";
         }
 
         if( diskInfo().diskState() == K3b::Device::STATE_COMPLETE ||
@@ -231,7 +230,7 @@ void K3b::Medium::analyseContent()
 
     // analyze filesystem
     if( d->content & ContentData ) {
-        //kDebug() << "(K3b::Medium) Checking file system.";
+        //qDebug() << "(K3b::Medium) Checking file system.";
 
         unsigned long startSec = 0;
 
@@ -255,10 +254,10 @@ void K3b::Medium::analyseContent()
             }
         }
         else {
-            kDebug() << "(K3b::Medium) ContentData is set and Toc is empty, disk is probably broken!";
+            qDebug() << "(K3b::Medium) ContentData is set and Toc is empty, disk is probably broken!";
         }
 
-        //kDebug() << "(K3b::Medium) Checking file system at " << startSec;
+        //qDebug() << "(K3b::Medium) Checking file system at " << startSec;
 
         // force the backend since we don't need decryption
         // which just slows down the whole process
@@ -267,7 +266,7 @@ void K3b::Medium::analyseContent()
         iso.setPlainIso9660( true );
         if( iso.open() ) {
             d->isoDesc = iso.primaryDescriptor();
-            kDebug() << "(K3b::Medium) found volume id from start sector " << startSec
+            qDebug() << "(K3b::Medium) found volume id from start sector " << startSec
                      << ": '" << d->isoDesc.volumeId << "'" ;
 
             if( const Iso9660Directory* firstDirEntry = iso.firstIsoDirEntry() ) {
@@ -277,19 +276,19 @@ void K3b::Medium::analyseContent()
                         d->content |= ContentVideoDVD;
                 }
                 else {
-                    kDebug() << "(K3b::Medium) checking for VCD.";
+                    qDebug() << "(K3b::Medium) checking for VCD.";
 
                     // check for VCD
                     const K3b::Iso9660Entry* vcdEntry = firstDirEntry->entry( "VCD/INFO.VCD" );
                     const K3b::Iso9660Entry* svcdEntry = firstDirEntry->entry( "SVCD/INFO.SVD" );
                     const K3b::Iso9660File* vcdInfoFile = 0;
                     if( vcdEntry ) {
-                        kDebug() << "(K3b::Medium) found vcd entry.";
+                        qDebug() << "(K3b::Medium) found vcd entry.";
                         if( vcdEntry->isFile() )
                             vcdInfoFile = static_cast<const K3b::Iso9660File*>(vcdEntry);
                     }
                     if( svcdEntry && !vcdInfoFile ) {
-                        kDebug() << "(K3b::Medium) found svcd entry.";
+                        qDebug() << "(K3b::Medium) found svcd entry.";
                         if( svcdEntry->isFile() )
                             vcdInfoFile = static_cast<const K3b::Iso9660File*>(svcdEntry);
                     }
@@ -306,7 +305,7 @@ void K3b::Medium::analyseContent()
                 }
             }
             else {
-                kDebug() << "(K3b::Medium) root ISO directory is null, disk is probably broken!";
+                qDebug() << "(K3b::Medium) root ISO directory is null, disk is probably broken!";
             }
         }  // opened iso9660
     }
@@ -421,9 +420,9 @@ QString K3b::Medium::longString( MediumStringFlags flags ) const
 
     if( diskInfo().diskState() == K3b::Device::STATE_COMPLETE ||
         diskInfo().diskState() == K3b::Device::STATE_INCOMPLETE  ) {
-        s += "<br/>" + i18np("%1 in 1 track", "%1 in %2 tracks",
-                             KIO::convertSize(diskInfo().size().mode1Bytes() ),
-                             d->toc.count() );
+        s += "<br/>" + i18np("%2 in %1 track", "%2 in %1 tracks",
+                             d->toc.count(),
+                             KIO::convertSize(diskInfo().size().mode1Bytes()) );
         if( diskInfo().numSessions() > 1 )
             s += i18np(" and %1 session", " and %1 sessions", diskInfo().numSessions() );
     }
@@ -500,31 +499,31 @@ QString K3b::Medium::beautifiedVolumeId() const
 }
 
 
-KIcon K3b::Medium::icon() const
+QIcon K3b::Medium::icon() const
 {
     if( diskInfo().diskState() == Device::STATE_NO_MEDIA ) {
-        return KIcon( "drive-optical" );
+        return QIcon::fromTheme( "media-optical" );
     }
     else if( diskInfo().diskState() == Device::STATE_EMPTY ) {
-        return KIcon( "media-optical-recordable" );
+        return QIcon::fromTheme( "media-optical-recordable" );
     }
     else if( content() == (ContentAudio | ContentData) ) {
-        return KIcon( "media-optical-mixed-cd" );
+        return QIcon::fromTheme( "media-optical-mixed-cd" );
     }
     else if( content() == ContentAudio ) {
-        return KIcon( "media-optical-audio" );
+        return QIcon::fromTheme( "media-optical-audio" );
     }
     else if( content() == ContentData ) {
-        return KIcon( "media-optical-data" );
+        return QIcon::fromTheme( "media-optical-data" );
     }
     else if( content() & ContentVideoDVD ) {
-        return KIcon( "media-optical-dvd-video" );
+        return QIcon::fromTheme( "media-optical-dvd-video" );
     }
     else if( content() & ContentVideoCD ) {
-        return KIcon( "media-optical-cd-video" );
+        return QIcon::fromTheme( "media-optical-cd-video" );
     }
     else {
-        return KIcon( "media-optical" );
+        return QIcon::fromTheme( "media-optical" );
     }
 }
 
@@ -574,6 +573,81 @@ bool K3b::Medium::sameMedium( const K3b::Medium& other ) const
 }
 
 
+// static
+QStringList K3b::Medium::mediaRequestStrings(QList< K3b::Medium > unsuitableMediums, K3b::Device::MediaTypes requestedMediaTypes, K3b::Device::MediaStates requestedMediaStates, const K3b::Msf& requestedSize, K3b::Device::Device* dev)
+{
+    QStringList toReturn;
+
+    bool okMediaType;
+    bool okMediaState;
+    bool okSize;
+    QString deviceString;
+
+    Q_FOREACH(K3b::Medium medium, unsuitableMediums) {
+        K3b::Device::Device *device = medium.device();
+
+        if ( dev && ( device->blockDeviceName() != dev->blockDeviceName() ) )
+            continue;
+
+        K3b::Device::DiskInfo diskInfo = medium.diskInfo();
+
+        okMediaType = ( diskInfo.mediaType() & requestedMediaTypes );
+        okMediaState = ( diskInfo.diskState() & requestedMediaStates );
+        okSize = ( diskInfo.capacity() >= requestedSize );
+
+        deviceString = device->vendor() + ' ' + device->description() + QLatin1String(" (") + device->blockDeviceName() + ')';
+
+        if (!okMediaType) {
+            QString desiredMedium;
+            if( requestedMediaTypes == (Device::MEDIA_WRITABLE_DVD|Device::MEDIA_WRITABLE_BD) ||
+                requestedMediaTypes == (Device::MEDIA_WRITABLE_DVD_DL|Device::MEDIA_WRITABLE_BD) )
+                desiredMedium = i18nc("To be shown when a DVD or Blu-ray is required but another type of medium is inserted.", "DVD or Blu-ray");
+            else if( requestedMediaTypes == Device::MEDIA_WRITABLE_BD )
+                desiredMedium = i18nc("To be shown when a Blu-ray is required but another type of medium is inserted.", "Blu-ray");
+            else if( requestedMediaTypes == Device::MEDIA_WRITABLE_CD )
+                desiredMedium = i18nc("To be shown when a CD is required but another type of medium is inserted.", "CD");
+            else if( requestedMediaTypes == Device::MEDIA_WRITABLE_DVD )
+                desiredMedium = i18nc("To be shown when a DVD is required but another type of medium is inserted.", "DVD");
+            else if( requestedMediaTypes == Device::MEDIA_WRITABLE_DVD_DL )
+                desiredMedium = i18nc("To be shown when a DVD-DL is required but another type of medium is inserted.", "DVD-DL");
+
+            if ( requestedMediaTypes == Device::MEDIA_REWRITABLE ) {
+                if ( desiredMedium.isEmpty() ) {
+                    desiredMedium = i18n("rewritable medium", desiredMedium);
+                }
+                else {
+                    desiredMedium = i18nc("%1 is type of medium (e.g. DVD)", "rewritable %1", desiredMedium);
+                }
+            }
+
+            if ( desiredMedium.isEmpty() )
+                desiredMedium = i18nc("To be shown when a specific type of medium is required but another type of medium is inserted.", "suitable medium");
+
+            toReturn.append(i18n("Medium in %1 is not a %2.", deviceString, desiredMedium));
+        }
+        else if (!okMediaState) {
+            QString desiredState;
+            if( requestedMediaStates == Device::STATE_EMPTY )
+                desiredState = i18nc("To be shown when an empty medium is required", "empty");
+            else if (requestedMediaStates == (Device::STATE_EMPTY|Device::STATE_INCOMPLETE) )
+                desiredState = i18nc("To be shown when an empty or appendable medium is required", "empty or appendable");
+            else if( requestedMediaStates == (Device::STATE_COMPLETE|Device::STATE_INCOMPLETE) )
+                desiredState = i18nc("To be shown when an non-empty medium is required", "non-empty");
+            else
+                desiredState = i18nc("To be shown when the state of the inserted medium is not suitable.", "suitable");
+
+            toReturn.append(i18n("Medium in %1 is not %2.", deviceString, desiredState));
+        }
+        else if ( !okSize ) {
+            toReturn.append(i18n("Capacity of the medium in %1 is smaller than required.", deviceString));
+        }
+    }
+
+    if (toReturn.isEmpty())
+        toReturn.append(mediaRequestString( requestedMediaTypes, requestedMediaStates, requestedSize, dev));
+    return toReturn;
+}
+
 // static
 QString K3b::Medium::mediaRequestString( Device::MediaTypes requestedMediaTypes, Device::MediaStates requestedMediaStates, const K3b::Msf& requestedSize, Device::Device* dev )
 {
